==> boost_1_82_0.tar.bz2: boost_1_82_0/libs/locale/doc/html/navtreedata.js <==
/*
@ @licstart  The following is the entire license notice for the
JavaScript code in this file.

Copyright (C) 1997-2017 by Dimitri van Heesch

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

You should have received a copy of the GNU General Public License along
with this program; if not, write to the Free Software Foundation, Inc.,
51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.

@licend  The above is the entire license notice
for the JavaScript code in this file
*/
var NAVTREE =
[
  [ "Boost.Locale", "index.html", [
    [ "What is Boost.Locale?", "index.html#main_intro", null ],
    [ "Tutorials", "index.html#main_tutorial", null ],
    [ "Introduction to C++ Standard Library localization support", "std_locales.html", [
      [ "Getting familiar with standard C++ Locales", "std_locales.html#std_locales_basics", null ],
      [ "Common Critical Problems with the Standard Library", "std_locales.html#std_locales_common", null ]
    ] ],
    [ "Using Boost.Locale", "using_boost_locale.html", "using_boost_locale" ],
    [ "Using Localization Backends", "using_localization_backends.html", [
      [ "When to use non-ICU backends", "using_localization_backends.html#when_to_use_non_icu_backends", null ],
      [ "Non-ICU Backends", "using_localization_backends.html#non_icu_backends", [
        [ "std - The standard C++ library backend", "using_localization_backends.html#std_backend", null ],
        [ "posix - POSIX 2008 C library", "using_localization_backends.html#posix_backend", null ],
        [ "winapi - Win32 API.", "using_localization_backends.html#winapi_backend", null ]
      ] ],
      [ "Supported Features", "using_localization_backends.html#supported_features_by_backends", null ],
      [ "Using Localization Backends", "using_localization_backends.html#using_localization_backends_sec", null ]
    ] ],
    [ "Recommendations and Myths", "recommendations_and_myths.html", [
      [ "Recommendations", "recommendations_and_myths.html#recommendations", null ],
      [ "Myths", "recommendations_and_myths.html#myths", [
        [ "To use Unicode in my application I should use wide strings everywhere.", "recommendations_and_myths.html#myths_wide", null ],
        [ "UTF-16 is the best encoding to work with.", "recommendations_and_myths.html#myths_utf16", null ]
      ] ]
    ] ],
    [ "Building the Library", "building_boost_locale.html", [
      [ "Building Boost.Locale", "building_boost_locale.html#building_boost_locale_bb", [
        [ "Dependencies", "building_boost_locale.html#bb_building_deps", null ],
        [ "Platform Notes", "building_boost_locale.html#bb_platform_opts", null ],
        [ "Building Process", "building_boost_locale.html#bb_building_proc", null ]
      ] ],
      [ "Build Options", "building_boost_locale.html#bb_build_opts", null ],
      [ "Running Unit Tests", "building_boost_locale.html#bb_build_test", null ],
      [ "Binary Compatibility", "building_boost_locale.html#binary_compatibility", null ]
    ] ],
    [ "Appendix", "appendix.html", "appendix" ],
    [ "Changelog", "changelog.html", null ],
    [ "Modules", "modules.html", "modules" ],
    [ "Namespaces", "namespaces.html", [
      [ "Namespace List", "namespaces.html", "namespaces_dup" ],
      [ "Namespace Members", "namespacemembers.html", [
        [ "All", "namespacemembers.html", "namespacemembers_dup" ],
        [ "Functions", "namespacemembers_func.html", "namespacemembers_func" ],
        [ "Variables", "namespacemembers_vars.html", null ],
        [ "Typedefs", "namespacemembers_type.html", null ],
        [ "Enumerations", "namespacemembers_enum.html", null ],
        [ "Enumerator", "namespacemembers_eval.html", null ]
      ] ]
    ] ],
    [ "Classes", "annotated.html", [
      [ "Class List", "annotated.html", "annotated_dup" ],
      [ "Class Hierarchy", "hierarchy.html", "hierarchy" ],
      [ "Class Members", "functions.html", [
        [ "All", "functions.html", "functions_dup" ],
        [ "Functions", "functions_func.html", "functions_func" ],
        [ "Variables", "functions_vars.html", null ],
        [ "Typedefs", "functions_type.html", null ],
        [ "Enumerations", "functions_enum.html", null ],
        [ "Enumerator", "functions_eval.html", null ]
      ] ]
    ] ],
    [ "Files", "files.html", [
      [ "File List", "files.html", "files_dup" ]
    ] ],
    [ "Examples", "examples.html", "examples" ]
  ] ]
];

var NAVTREEINDEX =
[
".html",
"classboost_1_1locale_1_1generator.html#a99fb69f05b0d3f86e37f52b8282c2f18",
"group__boundary.html#ga04f85fe2bbe5787f4e18403569614f11",
"group__message.html#ga0f8df25b168668a52084ca881306ddd6",
"structboost_1_1locale_1_1utf_1_1utf__traits.html#acd59f628af084f800f8a86cdd8124fd8"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';

==> boost_1_84_0.tar.bz2: boost_1_84_0/libs/locale/doc/html/navtreedata.js <==
/*
 @licstart  The following is the entire license notice for the JavaScript code in this file.

 The MIT License (MIT)

 Copyright (C) 1997-2020 by Dimitri van Heesch

 Permission is hereby granted, free of charge, to any person obtaining a copy of this software
 and associated documentation files (the "Software"), to deal in the Software without restriction,
 including without limitation the rights to use, copy, modify, merge, publish, distribute,
 sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in all copies or
 substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING
 BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

 @licend  The above is the entire license notice for the JavaScript code in this file
*/
var NAVTREE =
[
  [ "Boost.Locale", "index.html", [
    [ "What is Boost.Locale?", "index.html#main_intro", null ],
    [ "Tutorials", "index.html#main_tutorial", null ],
    [ "Introduction to C++ Standard Library localization support", "std_locales.html", [
      [ "Getting familiar with standard C++ Locales", "std_locales.html#std_locales_basics", null ],
      [ "Common Critical Problems with the Standard Library", "std_locales.html#std_locales_common", null ]
    ] ],
    [ "Using Boost.Locale", "using_boost_locale.html", "using_boost_locale" ],
    [ "Using Localization Backends", "using_localization_backends.html", [
      [ "When to use non-ICU backends", "using_localization_backends.html#when_to_use_non_icu_backends", null ],
      [ "Non-ICU Backends", "using_localization_backends.html#non_icu_backends", [
        [ "std - The standard C++ library backend", "using_localization_backends.html#std_backend", null ],
        [ "posix - POSIX 2008 C library", "using_localization_backends.html#posix_backend", null ],
        [ "winapi - Win32 API.", "using_localization_backends.html#winapi_backend", null ]
      ] ],
      [ "Supported Features", "using_localization_backends.html#supported_features_by_backends", null ],
      [ "Using Localization Backends", "using_localization_backends.html#using_localization_backends_sec", null ]
    ] ],
    [ "Recommendations and Myths", "recommendations_and_myths.html", [
      [ "Recommendations", "recommendations_and_myths.html#recommendations", null ],
      [ "Myths", "recommendations_and_myths.html#myths", [
        [ "To use Unicode in my application I should use wide strings everywhere.", "recommendations_and_myths.html#myths_wide", null ],
        [ "UTF-16 is the best encoding to work with.", "recommendations_and_myths.html#myths_utf16", null ]
      ] ]
    ] ],
    [ "Building the Library", "building_boost_locale.html", [
      [ "Building Boost.Locale", "building_boost_locale.html#building_boost_locale_bb", [
        [ "Dependencies", "building_boost_locale.html#bb_building_deps", null ],
        [ "Platform Notes", "building_boost_locale.html#bb_platform_opts", null ],
        [ "Building Process", "building_boost_locale.html#bb_building_proc", null ]
      ] ],
      [ "Build Options", "building_boost_locale.html#bb_build_opts", null ],
      [ "Running Unit Tests", "building_boost_locale.html#bb_build_test", null ],
      [ "Binary Compatibility", "building_boost_locale.html#binary_compatibility", null ]
    ] ],
    [ "Appendix", "appendix.html", "appendix" ],
    [ "Changelog", "changelog.html", null ],
    [ "Modules", "modules.html", "modules" ],
    [ "Namespaces", "namespaces.html", [
      [ "Namespace List", "namespaces.html", null ],
      [ "Namespace Members", "namespacemembers.html", [
        [ "All", "namespacemembers.html", "namespacemembers_dup" ],
        [ "Functions", "namespacemembers_func.html", "namespacemembers_func" ],
        [ "Variables", "namespacemembers_vars.html", null ],
        [ "Typedefs", "namespacemembers_type.html", null ],
        [ "Enumerations", "namespacemembers_enum.html", null ],
        [ "Enumerator", "namespacemembers_eval.html", null ]
      ] ]
    ] ],
    [ "Classes", "annotated.html", [
      [ "Class List", "annotated.html", "annotated_dup" ],
      [ "Class Hierarchy", "hierarchy.html", "hierarchy" ],
      [ "Class Members", "functions.html", [
        [ "All", "functions.html", "functions_dup" ],
        [ "Functions", "functions_func.html", "functions_func" ],
        [ "Variables", "functions_vars.html", null ],
        [ "Typedefs", "functions_type.html", null ],
        [ "Enumerations", "functions_enum.html", null ],
        [ "Enumerator", "functions_eval.html", null ]
      ] ]
    ] ],
    [ "Files", "files.html", [
      [ "File List", "files.html", "files_dup" ]
    ] ],
    [ "Examples", "examples.html", "examples" ]
  ] ]
];

var NAVTREEINDEX =
[
"annotated.html",
"classboost_1_1locale_1_1generator.html#a7b4458ef36df82bc9e359735c55203e8",
"group__boundary.html#ga315e4baac1059256cd9009a765670554",
"message_8hpp_source.html"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';
